@@ -1,10 +1,10 @@
 #![allow(clippy::deprecated)]
 use pyo3::prelude::*;
-use tokenizations::{get_alignments, get_charmap, get_original_spans, Alignment, CharMap};
+use tokenizations::{get_alignments, get_charmap, Alignment, CharMap};
 
 #[pymodule]
 fn tokenizations(_py: Python, m: &PyModule) -> PyResult<()> {
-    m.add("__version__", "0.7.2")?;
+    m.add("__version__", "0.8.3")?;
 
     #[pyfn(m, "get_alignments")]
     pub fn get_alignments_py(
@@ -20,14 +20,5 @@ fn tokenizations(_py: Python, m: &PyModule) -> PyResult<()> {
         Ok(get_charmap(a, b))
     }
 
-    #[pyfn(m, "get_original_spans")]
-    pub fn get_original_spans_py(
-        _py: Python,
-        tokens: Vec<&str>,
-        original_text: &str,
-    ) -> PyResult<Vec<Option<(usize, usize)>>> {
-        Ok(get_original_spans(&tokens, original_text))
-    }
-
     Ok(())
 }
